@@ -2,8 +2,6 @@ package SVG::TT::Graph::Bar;
 
 use strict;
 use Carp;
-use vars qw($VERSION);
-$VERSION = '0.09';
 
 use SVG::TT::Graph;
 use base qw(SVG::TT::Graph);
@@ -62,6 +60,7 @@ title, subtitle etc.
     'width'             => '300',
     'show_data_values'  => 1,
 
+    'max_scale_value'           => undef,
     'min_scale_value'           => '0',
 	'stagger_x_labels'  => 0,
     'rotate_x_labels'   => 0,
@@ -173,6 +172,11 @@ is '1', set to '0' if you don't want gaps.
 The point at which the Y axis starts, defaults to '0',
 if set to '' it will default to the minimum data value.
 
+=item max_scale_value()
+
+The maximum value for the Y axis.  If set to '', it will 
+default to the maximum data value.
+
 =item show_x_labels()
 
 Whether to show labels on the X axis or not, defaults
@@ -324,6 +328,7 @@ sub _set_defaults {
 		'style_sheet'       => '',
 	    'show_data_values'  => 1,
 	
+	    'max_scale_value'   => '',
 	    'min_scale_value'   => '0',
 		'scale_divisions'	=> '',
 		'bar_gap'			=> 1,
@@ -633,17 +638,25 @@ __DATA__
 		[% min_scale_value = min_value %]
 	[% END %]
 	
+	<!-- find ending value for scale on y axis -->
+	[% IF config.max_scale_value || config.max_scale_value == '0' %]
+		[% max_scale_value = config.max_scale_value %]
+	[% ELSE %]
+		<!-- setting highest value to be max_value as no max_scale_value defined -->
+		[% max_scale_value = max_value %]
+	[% END %]
+	
 	<!-- base line -->
 	[% base_line = h + y %]
 	
 	<!-- how much padding between largest bar and top of graph -->
-	[% IF (max_value - min_scale_value) == 0 %]
+	[% IF (max_scale_value - min_scale_value) == 0 %]
 		[% top_pad = 10 %]
 	[% ELSE %]
-		[% top_pad = (max_value - min_scale_value) / 20 %]	
+		[% top_pad = (max_scale_value - min_scale_value) / 20 %]	
 	[% END %]	
 	
-	[% scale_range = (max_value + top_pad) - min_scale_value %]
+	[% scale_range = (max_scale_value + top_pad) - min_scale_value %]
 
 	<!-- default to 10 scale_divisions if none have been set -->
 	[% IF config.scale_divisions %]
